#!/bin/bash

SKIP=6

IN_REC_DIR=`mp kombrink`/OOV/dirac/che/mlf/ref-rec_aligned/
IN_REF_DIR=`mp kombrink`/OOV/dirac/che/mlf/ref-rec_aligned/
IN_ALIGN_DIR=`mp kombrink`/OOV/dirac/che/mlf/NN/
CLASS_REF_MLF=`mp kombrink`/OOV/dirac/che/NN/mlfs/OOV-2860_corr_incorr_oov.wrd.mlf
CLASS_DIR=class
WEAK_PHN_MLF=`mp kombrink`/OOV/dirac/che/posteriors/phonecontext/evltest_OOV-2860.nn.mlf
REF_TIMED=`mp kombrink`/OOV/dirac/che/mlf/ref/timed/
SCOREOOV=

echo "stripping down mlfs (best paths)..."

./mlf.strip-to-selection.sh ${IN_ALIGN_DIR}/evltest_OOV-2860.aligned.wrd.mlf | awk 'NF==3{print "         0",$0;next}{print}' > aligned.mlf
./mlf.strip-to-selection.sh ${IN_REF_DIR}/evltest_OOV-2860.ref.pau.mlf > ref.pau.mlf
./mlf.strip-to-selection.sh ${IN_REF_DIR}/evltest_OOV-2860.ref.phn.mlf | awk '{sub(/^.*-/,"",$3);sub(/\+.*$/,"",$3);print $1,$2,$3}' > ref.phn.mlf
./mlf.strip-to-selection.sh ${IN_REC_DIR}/evltest_OOV-2860.rec.pau.mlf > rec.pau.mlf
./mlf.strip-to-selection.sh ${IN_REC_DIR}/evltest_OOV-2860.rec.phn.mlf | awk '{sub(/^.*-/,"",$3);sub(/\+.*$/,"",$3);print $1,$2,$3}' > rec.phn.mlf
./mlf.strip-to-selection.sh ${CLASS_REF_MLF} > 4class.ref.mlf
./mlf.strip-to-selection.sh ${WEAK_PHN_MLF} | awk '{sub(/^.*-/,"",$3);sub(/\+.*$/,"",$3);print $1,$2,$3}' > weak.phn.mlf
./mlf.strip-to-selection.sh ${REF_TIMED}/evltest_OOV-2860.pau.mlf > ref.timed.mlf

echo "STATISTICS" > stats.txt

$SCOREOOV 

echo "Total amount of words:" | tee >> stats.txt
cat aligned.mlf | awk 'NF==4{print $0}{}' | wc -l  | tee >> stats.txt

echo "Total amount OOVs:"  | tee >> stats.txt
cat selection.txt | awk 'NF>1{c+=(NF-1)/3;next}END{print c}'  | tee >> stats.txt

echo "Number of Utterances with OOVs:"  | tee >> stats.txt
cat selection.txt | awk 'NF>1{print;next}' | wc -l  | tee >> stats.txt

echo "Number of Utterances without OOVs:"  | tee >> stats.txt
cat selection.txt | awk 'NF==1{print;next}' | wc -l  | tee >> stats.txt

echo "OOV list" | tee >> stats.txt
cat selection.txt | awk 'NF>1{for (i=2;i<NF;i+=3){print $i};next}{}' | sort | uniq -c | sort -n  | tee >> stats.txt

echo "Reference stats"  | tee >> stats.txt
cat 4class.ref.mlf | awk 'BEGIN{delete t;}NF==3{t[$3]=t[$3]+$2-$1;}END{for (c in t) {print c,t[c]/10000000;}}' | tee >> stats.txt

IN_LATTICE=`mp kombrink`/OOV/dirac/che/latgen/lattices/evltest_OOV-2860/P4/lib/wlabs
IN_JOINPOSTDIR=`mp kombrink`/OOV/dirac/che/posteriors/joined/evltest_OOV-2860
JOINPOSTDIR=joinpost

rm -rf $JOINPOSTDIR
mkdir -p $JOINPOSTDIR

echo "done!"

echo "processing posterior features into asci format..."
for n in `cat selection.txt | awk '{print $1}'`; do
#    echo "processing utterance $n ..." 
    HList -r $IN_JOINPOSTDIR/${n}.fea > $JOINPOSTDIR/$n.asci
done;


echo "processing asci files into portable gray map format..."
./createpgm.sh

echo "producing NN output.."
rm -rf $CLASS_DIR
mkdir -p $CLASS_DIR

# prepare selection scp posterior feature file
cat selection.txt | awk '{print "'$IN_JOINPOSTDIR'/"$1".fea"}' > joinpostfea.scp

SFeaCat --STARTFRMEXT=$SKIP --ENDFRMEXT=$SKIP -H ./full_sys_fwd.ftr -S joinpostfea.scp -l $CLASS_DIR -T 1

# create asci scores
for sc in $CLASS_DIR/*.fea; do
  HList -r $sc | awk '{print exp($1),exp($2),exp($3),exp($4)}' > $CLASS_DIR/$(basename $sc .fea).asci
done;

echo "done!"

AUDIO_IN_DIR=../evltest-audio
AUDIO_OUT_DIR=audio

rm -rf $AUDIO_OUT_DIR
mkdir -p $AUDIO_OUT_DIR

echo "split up utterances from selection list..."
for utt in $(cat selection.txt|awk '{print $1}'); do
  echo $utt | \
   sed  's/.*[A,B]_//g' | tr -d 'fm' | tr '-' '_' | tr '_' ' ' | \
   awk '{system("sox '$AUDIO_IN_DIR'/en_"$1".wav '$AUDIO_IN_DIR/$utt'.wav trim "0.01*$3" "0.01*($4-$3));}'
done;

echo "create ogg files..."
for fn in $AUDIO_IN_DIR/che*.wav; do
    oggenc $fn -o $AUDIO_OUT_DIR/$(basename $fn .wav).ogg
done;


echo "done"
